/****************************************************************************
** Meta object code from reading C++ file 'kpViewScrollableContainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kolourpaint-26.04.2/kpViewScrollableContainer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kpViewScrollableContainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6kpGripE_t {};
} // unnamed namespace

template <> constexpr inline auto kpGrip::qt_create_metaobjectdata<qt_meta_tag_ZN6kpGripE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kpGrip",
        "beganDraw",
        "",
        "continuedDraw",
        "viewDX",
        "viewDY",
        "dueToDragScroll",
        "cancelledDraw",
        "endedDraw",
        "statusMessageChanged",
        "string",
        "releasedAllButtons"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'beganDraw'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'continuedDraw'
        QtMocHelpers::SignalData<void(int, int, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'cancelledDraw'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endedDraw'
        QtMocHelpers::SignalData<void(int, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'statusMessageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'releasedAllButtons'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kpGrip, qt_meta_tag_ZN6kpGripE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kpGrip::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6kpGripE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6kpGripE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6kpGripE_t>.metaTypes,
    nullptr
} };

void kpGrip::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kpGrip *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->beganDraw(); break;
        case 1: _t->continuedDraw((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->cancelledDraw(); break;
        case 3: _t->endedDraw((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->statusMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->releasedAllButtons(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (kpGrip::*)()>(_a, &kpGrip::beganDraw, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpGrip::*)(int , int , bool )>(_a, &kpGrip::continuedDraw, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpGrip::*)()>(_a, &kpGrip::cancelledDraw, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpGrip::*)(int , int )>(_a, &kpGrip::endedDraw, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpGrip::*)(const QString & )>(_a, &kpGrip::statusMessageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpGrip::*)()>(_a, &kpGrip::releasedAllButtons, 5))
            return;
    }
}

const QMetaObject *kpGrip::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kpGrip::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6kpGripE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int kpGrip::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void kpGrip::beganDraw()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void kpGrip::continuedDraw(int _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void kpGrip::cancelledDraw()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void kpGrip::endedDraw(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void kpGrip::statusMessageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void kpGrip::releasedAllButtons()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN25kpViewScrollableContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto kpViewScrollableContainer::qt_create_metaobjectdata<qt_meta_tag_ZN25kpViewScrollableContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kpViewScrollableContainer",
        "contentsMoved",
        "",
        "beganDocResize",
        "continuedDocResize",
        "QSize",
        "size",
        "cancelledDocResize",
        "endedDocResize",
        "statusMessageChanged",
        "string",
        "resized",
        "recalculateStatusMessage",
        "updateGrips",
        "beginDragScroll",
        "zoomLevel",
        "bool*",
        "didSomething",
        "endDragScroll",
        "slotGripBeganDraw",
        "slotGripContinuedDraw",
        "viewDX",
        "viewDY",
        "dueToScrollView",
        "slotGripCancelledDraw",
        "slotGripEndedDraw",
        "slotGripStatusMessageChanged",
        "slotContentsMoved",
        "slotViewDestroyed",
        "slotDragScroll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contentsMoved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'beganDocResize'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'continuedDocResize'
        QtMocHelpers::SignalData<void(const QSize &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'cancelledDocResize'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endedDocResize'
        QtMocHelpers::SignalData<void(const QSize &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'statusMessageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'resized'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'recalculateStatusMessage'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateGrips'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'beginDragScroll'
        QtMocHelpers::SlotData<bool(int, bool *)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'beginDragScroll'
        QtMocHelpers::SlotData<bool(int)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'endDragScroll'
        QtMocHelpers::SlotData<bool()>(18, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotGripBeganDraw'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGripContinuedDraw'
        QtMocHelpers::SlotData<void(int, int, bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'slotGripCancelledDraw'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGripEndedDraw'
        QtMocHelpers::SlotData<void(int, int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'slotGripStatusMessageChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'slotContentsMoved'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotViewDestroyed'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDragScroll'
        QtMocHelpers::SlotData<bool(bool *)>(29, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotDragScroll'
        QtMocHelpers::SlotData<bool()>(29, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kpViewScrollableContainer, qt_meta_tag_ZN25kpViewScrollableContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kpViewScrollableContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25kpViewScrollableContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25kpViewScrollableContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25kpViewScrollableContainerE_t>.metaTypes,
    nullptr
} };

void kpViewScrollableContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kpViewScrollableContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contentsMoved(); break;
        case 1: _t->beganDocResize(); break;
        case 2: _t->continuedDocResize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 3: _t->cancelledDocResize(); break;
        case 4: _t->endedDocResize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 5: _t->statusMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->resized(); break;
        case 7: _t->recalculateStatusMessage(); break;
        case 8: _t->updateGrips(); break;
        case 9: { bool _r = _t->beginDragScroll((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->beginDragScroll((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->endDragScroll();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->slotGripBeganDraw(); break;
        case 13: _t->slotGripContinuedDraw((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->slotGripCancelledDraw(); break;
        case 15: _t->slotGripEndedDraw((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->slotGripStatusMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->slotContentsMoved(); break;
        case 18: _t->slotViewDestroyed(); break;
        case 19: { bool _r = _t->slotDragScroll((*reinterpret_cast<std::add_pointer_t<bool*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->slotDragScroll();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)()>(_a, &kpViewScrollableContainer::contentsMoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)()>(_a, &kpViewScrollableContainer::beganDocResize, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)(const QSize & )>(_a, &kpViewScrollableContainer::continuedDocResize, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)()>(_a, &kpViewScrollableContainer::cancelledDocResize, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)(const QSize & )>(_a, &kpViewScrollableContainer::endedDocResize, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)(const QString & )>(_a, &kpViewScrollableContainer::statusMessageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpViewScrollableContainer::*)()>(_a, &kpViewScrollableContainer::resized, 6))
            return;
    }
}

const QMetaObject *kpViewScrollableContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kpViewScrollableContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25kpViewScrollableContainerE_t>.strings))
        return static_cast<void*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int kpViewScrollableContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void kpViewScrollableContainer::contentsMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void kpViewScrollableContainer::beganDocResize()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void kpViewScrollableContainer::continuedDocResize(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void kpViewScrollableContainer::cancelledDocResize()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void kpViewScrollableContainer::endedDocResize(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void kpViewScrollableContainer::statusMessageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void kpViewScrollableContainer::resized()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
