/****************************************************************************
** Meta object code from reading C++ file 'kpToolToolBar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kolourpaint-26.04.2/widgets/toolbars/kpToolToolBar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kpToolToolBar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13kpToolToolBarE_t {};
} // unnamed namespace

template <> constexpr inline auto kpToolToolBar::qt_create_metaobjectdata<qt_meta_tag_ZN13kpToolToolBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kpToolToolBar",
        "sigToolSelected",
        "",
        "kpTool*",
        "tool",
        "toolWidgetOptionSelected",
        "slotToolButtonClicked",
        "slotToolActionActivated",
        "adjustToOrientation",
        "Qt::Orientation",
        "o",
        "slotIconSizeChanged",
        "QSize",
        "slotToolButtonStyleChanged",
        "Qt::ToolButtonStyle",
        "style"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigToolSelected'
        QtMocHelpers::SignalData<void(kpTool *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'toolWidgetOptionSelected'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToolButtonClicked'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToolActionActivated'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'adjustToOrientation'
        QtMocHelpers::SlotData<void(Qt::Orientation)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotIconSizeChanged'
        QtMocHelpers::SlotData<void(const QSize &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'slotToolButtonStyleChanged'
        QtMocHelpers::SlotData<void(Qt::ToolButtonStyle)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kpToolToolBar, qt_meta_tag_ZN13kpToolToolBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kpToolToolBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KToolBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13kpToolToolBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13kpToolToolBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13kpToolToolBarE_t>.metaTypes,
    nullptr
} };

void kpToolToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kpToolToolBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigToolSelected((*reinterpret_cast<std::add_pointer_t<kpTool*>>(_a[1]))); break;
        case 1: _t->toolWidgetOptionSelected(); break;
        case 2: _t->slotToolButtonClicked(); break;
        case 3: _t->slotToolActionActivated(); break;
        case 4: _t->adjustToOrientation((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1]))); break;
        case 5: _t->slotIconSizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 6: _t->slotToolButtonStyleChanged((*reinterpret_cast<std::add_pointer_t<Qt::ToolButtonStyle>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (kpToolToolBar::*)(kpTool * )>(_a, &kpToolToolBar::sigToolSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpToolToolBar::*)()>(_a, &kpToolToolBar::toolWidgetOptionSelected, 1))
            return;
    }
}

const QMetaObject *kpToolToolBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kpToolToolBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13kpToolToolBarE_t>.strings))
        return static_cast<void*>(this);
    return KToolBar::qt_metacast(_clname);
}

int kpToolToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KToolBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void kpToolToolBar::sigToolSelected(kpTool * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kpToolToolBar::toolWidgetOptionSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
