/****************************************************************************
** Meta object code from reading C++ file 'kpColorCells.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kolourpaint-26.04.2/widgets/kpColorCells.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kpColorCells.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12kpColorCellsE_t {};
} // unnamed namespace

template <> constexpr inline auto kpColorCells::qt_create_metaobjectdata<qt_meta_tag_ZN12kpColorCellsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kpColorCells",
        "foregroundColorChanged",
        "",
        "kpColor",
        "color",
        "backgroundColorChanged",
        "rowCountChanged",
        "rowCount",
        "nameChanged",
        "name",
        "urlChanged",
        "QUrl",
        "url",
        "isModifiedChanged",
        "isModified",
        "setModified",
        "slotColorSelected",
        "cell",
        "QColor",
        "Qt::MouseButton",
        "button",
        "slotColorDoubleClicked",
        "slotColorChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'foregroundColorChanged'
        QtMocHelpers::SignalData<void(const kpColor &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void(const kpColor &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'rowCountChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'isModifiedChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setModified'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotColorSelected'
        QtMocHelpers::SlotData<void(int, const QColor &, Qt::MouseButton)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 18, 4 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'slotColorDoubleClicked'
        QtMocHelpers::SlotData<void(int, const QColor &)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 18, 4 },
        }}),
        // Slot 'slotColorChanged'
        QtMocHelpers::SlotData<void(int, const QColor &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 18, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kpColorCells, qt_meta_tag_ZN12kpColorCellsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kpColorCells::staticMetaObject = { {
    QMetaObject::SuperData::link<kpColorCellsBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12kpColorCellsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12kpColorCellsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12kpColorCellsE_t>.metaTypes,
    nullptr
} };

void kpColorCells::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kpColorCells *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->foregroundColorChanged((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1]))); break;
        case 1: _t->backgroundColorChanged((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1]))); break;
        case 2: _t->rowCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->isModifiedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setModified(); break;
        case 7: _t->slotColorSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[3]))); break;
        case 8: _t->slotColorDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 9: _t->slotColorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (kpColorCells::*)(const kpColor & )>(_a, &kpColorCells::foregroundColorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpColorCells::*)(const kpColor & )>(_a, &kpColorCells::backgroundColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpColorCells::*)(int )>(_a, &kpColorCells::rowCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpColorCells::*)(const QString & )>(_a, &kpColorCells::nameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpColorCells::*)(const QUrl & )>(_a, &kpColorCells::urlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpColorCells::*)(bool )>(_a, &kpColorCells::isModifiedChanged, 5))
            return;
    }
}

const QMetaObject *kpColorCells::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kpColorCells::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12kpColorCellsE_t>.strings))
        return static_cast<void*>(this);
    return kpColorCellsBase::qt_metacast(_clname);
}

int kpColorCells::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = kpColorCellsBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void kpColorCells::foregroundColorChanged(const kpColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kpColorCells::backgroundColorChanged(const kpColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void kpColorCells::rowCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void kpColorCells::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void kpColorCells::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void kpColorCells::isModifiedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
