/****************************************************************************
** Meta object code from reading C++ file 'kpMainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kolourpaint-26.04.2/mainWindow/kpMainWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kpMainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12kpMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto kpMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN12kpMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kpMainWindow",
        "slotScrollViewAfterScroll",
        "",
        "slotUpdateCaption",
        "slotDocumentRestored",
        "updateToolOptionPrevNextActionsEnabled",
        "updateActionDrawOpaqueChecked",
        "slotToolSelected",
        "kpTool*",
        "tool",
        "slotDragScroll",
        "QPoint",
        "docPoint",
        "docLastPoint",
        "zoomLevel",
        "bool*",
        "didSomething",
        "slotEndDragScroll",
        "slotBeganDocResize",
        "slotContinuedDocResize",
        "QSize",
        "size",
        "slotCancelledDocResize",
        "slotEndedDocResize",
        "slotDocResizeMessageChanged",
        "string",
        "slotActionPrevToolOptionGroup1",
        "slotActionNextToolOptionGroup1",
        "slotActionPrevToolOptionGroup2",
        "slotActionNextToolOptionGroup2",
        "slotActionDrawOpaqueToggled",
        "slotActionDrawColorSimilarity",
        "slotToolRectSelection",
        "slotToolEllipticalSelection",
        "slotToolFreeFormSelection",
        "slotToolText",
        "slotNew",
        "slotOpen",
        "slotOpenRecent",
        "QUrl",
        "url",
        "slotRecentListCleared",
        "slotScan",
        "slotScanned",
        "QImage",
        "image",
        "slotScreenshot",
        "slotMakeScreenshot",
        "slotProperties",
        "save",
        "localOnly",
        "slotSave",
        "saveAs",
        "slotSaveAs",
        "slotExport",
        "slotEnableReload",
        "slotReload",
        "sendPreviewToPrinter",
        "QPrinter*",
        "printer",
        "slotPrint",
        "slotPrintPreview",
        "slotMail",
        "queryCloseDocument",
        "queryClose",
        "slotClose",
        "slotQuit",
        "slotCut",
        "slotCopy",
        "slotEnablePaste",
        "slotPaste",
        "slotPasteInNewWindow",
        "slotDelete",
        "slotSelectAll",
        "slotDeselect",
        "slotCopyToFile",
        "slotPasteFromFile",
        "slotShowGridToggled",
        "slotActualSize",
        "slotFitToPage",
        "slotFitToWidth",
        "slotFitToHeight",
        "slotZoomIn",
        "slotZoomOut",
        "slotZoom",
        "slotDestroyThumbnail",
        "slotDestroyThumbnailInitatedByUser",
        "slotCreateThumbnail",
        "slotSaveThumbnailGeometry",
        "slotShowThumbnailToggled",
        "updateThumbnailZoomed",
        "slotZoomedThumbnailToggled",
        "slotThumbnailShowRectangleToggled",
        "slotImageMenuUpdateDueToSelection",
        "slotCrop",
        "slotResizeScale",
        "slotAutoCrop",
        "slotFlip",
        "slotMirror",
        "slotRotate",
        "slotRotate270",
        "slotRotate90",
        "slotSkew",
        "slotConvertToBlackAndWhite",
        "slotConvertToGrayscale",
        "slotInvertColors",
        "slotClear",
        "slotMakeConfidential",
        "slotMoreEffects",
        "slotUpdateColorsDeleteRowActionEnabled",
        "slotColorsDefault",
        "slotColorsKDE",
        "slotColorsOpen",
        "slotColorsReload",
        "slotColorsSave",
        "slotColorsSaveAs",
        "slotColorsAppendRow",
        "slotColorsDeleteRow",
        "slotFullScreen",
        "slotEnableSettingsShowPath",
        "slotShowPathToggled",
        "slotDrawAntiAliasedToggled",
        "on",
        "slotKeyBindings",
        "setStatusBarMessage",
        "message",
        "setStatusBarShapePoints",
        "startPoint",
        "endPoint",
        "setStatusBarShapeSize",
        "setStatusBarDocSize",
        "setStatusBarZoom",
        "zoom",
        "recalculateStatusBarMessage",
        "recalculateStatusBarShape",
        "recalculateStatusBar",
        "slotTextFontFamilyChanged",
        "slotTextFontSizeChanged",
        "slotTextBoldChanged",
        "slotTextItalicChanged",
        "slotTextUnderlineChanged",
        "slotTextStrikeThruChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotScrollViewAfterScroll'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateCaption'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDocumentRestored'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateToolOptionPrevNextActionsEnabled'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateActionDrawOpaqueChecked'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToolSelected'
        QtMocHelpers::SlotData<void(kpTool *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotDragScroll'
        QtMocHelpers::SlotData<bool(const QPoint &, const QPoint &, int, bool *)>(10, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 }, { QMetaType::Int, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotEndDragScroll'
        QtMocHelpers::SlotData<bool()>(17, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotBeganDocResize'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotContinuedDocResize'
        QtMocHelpers::SlotData<void(const QSize &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'slotCancelledDocResize'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEndedDocResize'
        QtMocHelpers::SlotData<void(const QSize &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'slotDocResizeMessageChanged'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'slotActionPrevToolOptionGroup1'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActionNextToolOptionGroup1'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActionPrevToolOptionGroup2'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActionNextToolOptionGroup2'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActionDrawOpaqueToggled'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActionDrawColorSimilarity'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToolRectSelection'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToolEllipticalSelection'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToolFreeFormSelection'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToolText'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNew'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpen'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenRecent'
        QtMocHelpers::SlotData<void(const QUrl &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotRecentListCleared'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotScan'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotScanned'
        QtMocHelpers::SlotData<void(const QImage &, int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotScreenshot'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMakeScreenshot'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotProperties'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<bool(bool)>(49, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 50 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(49, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'slotSave'
        QtMocHelpers::SlotData<bool()>(51, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<bool(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 50 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<bool()>(52, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'slotSaveAs'
        QtMocHelpers::SlotData<bool()>(53, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotExport'
        QtMocHelpers::SlotData<bool()>(54, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotEnableReload'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReload'
        QtMocHelpers::SlotData<bool()>(56, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'sendPreviewToPrinter'
        QtMocHelpers::SlotData<void(QPrinter *)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'slotPrint'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPrintPreview'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMail'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'queryCloseDocument'
        QtMocHelpers::SlotData<bool()>(63, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'queryClose'
        QtMocHelpers::SlotData<bool()>(64, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotClose'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotQuit'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCut'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnablePaste'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPaste'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPasteInNewWindow'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDelete'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeselect'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyToFile'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPasteFromFile'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowGridToggled'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActualSize'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFitToPage'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFitToWidth'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFitToHeight'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoom'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDestroyThumbnail'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDestroyThumbnailInitatedByUser'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateThumbnail'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveThumbnailGeometry'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowThumbnailToggled'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateThumbnailZoomed'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomedThumbnailToggled'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotThumbnailShowRectangleToggled'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImageMenuUpdateDueToSelection'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCrop'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotResizeScale'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAutoCrop'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFlip'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMirror'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRotate'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRotate270'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRotate90'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSkew'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConvertToBlackAndWhite'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConvertToGrayscale'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInvertColors'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClear'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMakeConfidential'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoreEffects'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateColorsDeleteRowActionEnabled'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorsDefault'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorsKDE'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorsOpen'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorsReload'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorsSave'
        QtMocHelpers::SlotData<bool()>(114, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotColorsSaveAs'
        QtMocHelpers::SlotData<bool()>(115, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'slotColorsAppendRow'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotColorsDeleteRow'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFullScreen'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnableSettingsShowPath'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowPathToggled'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDrawAntiAliasedToggled'
        QtMocHelpers::SlotData<void(bool)>(121, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 122 },
        }}),
        // Slot 'slotKeyBindings'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setStatusBarMessage'
        QtMocHelpers::SlotData<void(const QString &)>(124, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 125 },
        }}),
        // Slot 'setStatusBarMessage'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setStatusBarShapePoints'
        QtMocHelpers::SlotData<void(const QPoint &, const QPoint &)>(126, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 127 }, { 0x80000000 | 11, 128 },
        }}),
        // Slot 'setStatusBarShapePoints'
        QtMocHelpers::SlotData<void(const QPoint &)>(126, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 11, 127 },
        }}),
        // Slot 'setStatusBarShapePoints'
        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setStatusBarShapeSize'
        QtMocHelpers::SlotData<void(const QSize &)>(129, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setStatusBarShapeSize'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setStatusBarDocSize'
        QtMocHelpers::SlotData<void(const QSize &)>(130, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setStatusBarDocSize'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setStatusBarZoom'
        QtMocHelpers::SlotData<void(int)>(131, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 132 },
        }}),
        // Slot 'setStatusBarZoom'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'recalculateStatusBarMessage'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recalculateStatusBarShape'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recalculateStatusBar'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTextFontFamilyChanged'
        QtMocHelpers::SlotData<void()>(136, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTextFontSizeChanged'
        QtMocHelpers::SlotData<void()>(137, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTextBoldChanged'
        QtMocHelpers::SlotData<void()>(138, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTextItalicChanged'
        QtMocHelpers::SlotData<void()>(139, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTextUnderlineChanged'
        QtMocHelpers::SlotData<void()>(140, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTextStrikeThruChanged'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kpMainWindow, qt_meta_tag_ZN12kpMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kpMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12kpMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12kpMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12kpMainWindowE_t>.metaTypes,
    nullptr
} };

void kpMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kpMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotScrollViewAfterScroll(); break;
        case 1: _t->slotUpdateCaption(); break;
        case 2: _t->slotDocumentRestored(); break;
        case 3: _t->updateToolOptionPrevNextActionsEnabled(); break;
        case 4: _t->updateActionDrawOpaqueChecked(); break;
        case 5: _t->slotToolSelected((*reinterpret_cast<std::add_pointer_t<kpTool*>>(_a[1]))); break;
        case 6: { bool _r = _t->slotDragScroll((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->slotEndDragScroll();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->slotBeganDocResize(); break;
        case 9: _t->slotContinuedDocResize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 10: _t->slotCancelledDocResize(); break;
        case 11: _t->slotEndedDocResize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 12: _t->slotDocResizeMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->slotActionPrevToolOptionGroup1(); break;
        case 14: _t->slotActionNextToolOptionGroup1(); break;
        case 15: _t->slotActionPrevToolOptionGroup2(); break;
        case 16: _t->slotActionNextToolOptionGroup2(); break;
        case 17: _t->slotActionDrawOpaqueToggled(); break;
        case 18: _t->slotActionDrawColorSimilarity(); break;
        case 19: _t->slotToolRectSelection(); break;
        case 20: _t->slotToolEllipticalSelection(); break;
        case 21: _t->slotToolFreeFormSelection(); break;
        case 22: _t->slotToolText(); break;
        case 23: _t->slotNew(); break;
        case 24: _t->slotOpen(); break;
        case 25: _t->slotOpenRecent((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 26: _t->slotRecentListCleared(); break;
        case 27: _t->slotScan(); break;
        case 28: _t->slotScanned((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 29: _t->slotScreenshot(); break;
        case 30: _t->slotMakeScreenshot(); break;
        case 31: _t->slotProperties(); break;
        case 32: { bool _r = _t->save((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->slotSave();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->saveAs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->saveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->slotSaveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->slotExport();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->slotEnableReload(); break;
        case 40: { bool _r = _t->slotReload();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->sendPreviewToPrinter((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 42: _t->slotPrint(); break;
        case 43: _t->slotPrintPreview(); break;
        case 44: _t->slotMail(); break;
        case 45: { bool _r = _t->queryCloseDocument();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->queryClose();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->slotClose(); break;
        case 48: _t->slotQuit(); break;
        case 49: _t->slotCut(); break;
        case 50: _t->slotCopy(); break;
        case 51: _t->slotEnablePaste(); break;
        case 52: _t->slotPaste(); break;
        case 53: _t->slotPasteInNewWindow(); break;
        case 54: _t->slotDelete(); break;
        case 55: _t->slotSelectAll(); break;
        case 56: _t->slotDeselect(); break;
        case 57: _t->slotCopyToFile(); break;
        case 58: _t->slotPasteFromFile(); break;
        case 59: _t->slotShowGridToggled(); break;
        case 60: _t->slotActualSize(); break;
        case 61: _t->slotFitToPage(); break;
        case 62: _t->slotFitToWidth(); break;
        case 63: _t->slotFitToHeight(); break;
        case 64: _t->slotZoomIn(); break;
        case 65: _t->slotZoomOut(); break;
        case 66: _t->slotZoom(); break;
        case 67: _t->slotDestroyThumbnail(); break;
        case 68: _t->slotDestroyThumbnailInitatedByUser(); break;
        case 69: _t->slotCreateThumbnail(); break;
        case 70: _t->slotSaveThumbnailGeometry(); break;
        case 71: _t->slotShowThumbnailToggled(); break;
        case 72: _t->updateThumbnailZoomed(); break;
        case 73: _t->slotZoomedThumbnailToggled(); break;
        case 74: _t->slotThumbnailShowRectangleToggled(); break;
        case 75: _t->slotImageMenuUpdateDueToSelection(); break;
        case 76: _t->slotCrop(); break;
        case 77: _t->slotResizeScale(); break;
        case 78: _t->slotAutoCrop(); break;
        case 79: _t->slotFlip(); break;
        case 80: _t->slotMirror(); break;
        case 81: _t->slotRotate(); break;
        case 82: _t->slotRotate270(); break;
        case 83: _t->slotRotate90(); break;
        case 84: _t->slotSkew(); break;
        case 85: _t->slotConvertToBlackAndWhite(); break;
        case 86: _t->slotConvertToGrayscale(); break;
        case 87: _t->slotInvertColors(); break;
        case 88: _t->slotClear(); break;
        case 89: _t->slotMakeConfidential(); break;
        case 90: _t->slotMoreEffects(); break;
        case 91: _t->slotUpdateColorsDeleteRowActionEnabled(); break;
        case 92: _t->slotColorsDefault(); break;
        case 93: _t->slotColorsKDE(); break;
        case 94: _t->slotColorsOpen(); break;
        case 95: _t->slotColorsReload(); break;
        case 96: { bool _r = _t->slotColorsSave();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 97: { bool _r = _t->slotColorsSaveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 98: _t->slotColorsAppendRow(); break;
        case 99: _t->slotColorsDeleteRow(); break;
        case 100: _t->slotFullScreen(); break;
        case 101: _t->slotEnableSettingsShowPath(); break;
        case 102: _t->slotShowPathToggled(); break;
        case 103: _t->slotDrawAntiAliasedToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 104: _t->slotKeyBindings(); break;
        case 105: _t->setStatusBarMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 106: _t->setStatusBarMessage(); break;
        case 107: _t->setStatusBarShapePoints((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 108: _t->setStatusBarShapePoints((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 109: _t->setStatusBarShapePoints(); break;
        case 110: _t->setStatusBarShapeSize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 111: _t->setStatusBarShapeSize(); break;
        case 112: _t->setStatusBarDocSize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 113: _t->setStatusBarDocSize(); break;
        case 114: _t->setStatusBarZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 115: _t->setStatusBarZoom(); break;
        case 116: _t->recalculateStatusBarMessage(); break;
        case 117: _t->recalculateStatusBarShape(); break;
        case 118: _t->recalculateStatusBar(); break;
        case 119: _t->slotTextFontFamilyChanged(); break;
        case 120: _t->slotTextFontSizeChanged(); break;
        case 121: _t->slotTextBoldChanged(); break;
        case 122: _t->slotTextItalicChanged(); break;
        case 123: _t->slotTextUnderlineChanged(); break;
        case 124: _t->slotTextStrikeThruChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *kpMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kpMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12kpMainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int kpMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 125)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 125;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 125)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 125;
    }
    return _id;
}
QT_WARNING_POP
