/****************************************************************************
** Meta object code from reading C++ file 'kpTool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kolourpaint-26.04.2/tools/kpTool.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kpTool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6kpToolE_t {};
} // unnamed namespace

template <> constexpr inline auto kpTool::qt_create_metaobjectdata<qt_meta_tag_ZN6kpToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kpTool",
        "beganDraw",
        "",
        "QPoint",
        "point",
        "movedAndAboutToDraw",
        "currentPoint",
        "lastPoint",
        "zoomLevel",
        "bool*",
        "scrolled",
        "endedDraw",
        "cancelledShape",
        "actionActivated",
        "userMessageChanged",
        "userMessage",
        "userShapePointsChanged",
        "startPoint",
        "endPoint",
        "userShapeSizeChanged",
        "QSize",
        "size",
        "somethingBelowTheCursorChanged",
        "slotColorsSwappedInternal",
        "kpColor",
        "newForegroundColor",
        "newBackgroundColor",
        "slotForegroundColorChangedInternal",
        "color",
        "slotBackgroundColorChangedInternal",
        "slotColorSimilarityChangedInternal",
        "similarity",
        "processedSimilarity",
        "slotColorsSwapped",
        "slotForegroundColorChanged",
        "slotBackgroundColorChanged",
        "slotColorSimilarityChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'beganDraw'
        QtMocHelpers::SignalData<void(const QPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'movedAndAboutToDraw'
        QtMocHelpers::SignalData<void(const QPoint &, const QPoint &, int, bool *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { 0x80000000 | 3, 7 }, { QMetaType::Int, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'endedDraw'
        QtMocHelpers::SignalData<void(const QPoint &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'cancelledShape'
        QtMocHelpers::SignalData<void(const QPoint &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'actionActivated'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userMessageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'userShapePointsChanged'
        QtMocHelpers::SignalData<void(const QPoint &, const QPoint &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 17 }, { 0x80000000 | 3, 18 },
        }}),
        // Signal 'userShapePointsChanged'
        QtMocHelpers::SignalData<void(const QPoint &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 17 },
        }}),
        // Signal 'userShapePointsChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'userShapeSizeChanged'
        QtMocHelpers::SignalData<void(const QSize &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'somethingBelowTheCursorChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotColorsSwappedInternal'
        QtMocHelpers::SlotData<void(const kpColor &, const kpColor &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 26 },
        }}),
        // Slot 'slotForegroundColorChangedInternal'
        QtMocHelpers::SlotData<void(const kpColor &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 28 },
        }}),
        // Slot 'slotBackgroundColorChangedInternal'
        QtMocHelpers::SlotData<void(const kpColor &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 28 },
        }}),
        // Slot 'slotColorSimilarityChangedInternal'
        QtMocHelpers::SlotData<void(double, int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 }, { QMetaType::Int, 32 },
        }}),
        // Slot 'slotColorsSwapped'
        QtMocHelpers::SlotData<void(const kpColor &, const kpColor &)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 24, 2 }, { 0x80000000 | 24, 2 },
        }}),
        // Slot 'slotForegroundColorChanged'
        QtMocHelpers::SlotData<void(const kpColor &)>(34, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'slotBackgroundColorChanged'
        QtMocHelpers::SlotData<void(const kpColor &)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 24, 2 },
        }}),
        // Slot 'slotColorSimilarityChanged'
        QtMocHelpers::SlotData<void(double, int)>(36, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 2 }, { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<kpTool, qt_meta_tag_ZN6kpToolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kpTool::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6kpToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6kpToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6kpToolE_t>.metaTypes,
    nullptr
} };

void kpTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<kpTool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->beganDraw((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 1: _t->movedAndAboutToDraw((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[4]))); break;
        case 2: _t->endedDraw((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->cancelledShape((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 4: _t->actionActivated(); break;
        case 5: _t->userMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->userShapePointsChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 7: _t->userShapePointsChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->userShapePointsChanged(); break;
        case 9: _t->userShapeSizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 10: _t->somethingBelowTheCursorChanged(); break;
        case 11: _t->slotColorsSwappedInternal((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[2]))); break;
        case 12: _t->slotForegroundColorChangedInternal((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1]))); break;
        case 13: _t->slotBackgroundColorChangedInternal((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1]))); break;
        case 14: _t->slotColorSimilarityChangedInternal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->slotColorsSwapped((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[2]))); break;
        case 16: _t->slotForegroundColorChanged((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1]))); break;
        case 17: _t->slotBackgroundColorChanged((*reinterpret_cast<std::add_pointer_t<kpColor>>(_a[1]))); break;
        case 18: _t->slotColorSimilarityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QPoint & )>(_a, &kpTool::beganDraw, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QPoint & , const QPoint & , int , bool * )>(_a, &kpTool::movedAndAboutToDraw, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QPoint & )>(_a, &kpTool::endedDraw, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QPoint & )>(_a, &kpTool::cancelledShape, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)()>(_a, &kpTool::actionActivated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QString & )>(_a, &kpTool::userMessageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QPoint & , const QPoint & )>(_a, &kpTool::userShapePointsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (kpTool::*)(const QSize & )>(_a, &kpTool::userShapeSizeChanged, 9))
            return;
    }
}

const QMetaObject *kpTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kpTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6kpToolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kpTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void kpTool::beganDraw(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kpTool::movedAndAboutToDraw(const QPoint & _t1, const QPoint & _t2, int _t3, bool * _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void kpTool::endedDraw(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void kpTool::cancelledShape(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void kpTool::actionActivated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void kpTool::userMessageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void kpTool::userShapePointsChanged(const QPoint & _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 9
void kpTool::userShapeSizeChanged(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
